@@ -1,5 +1,6 @@
 # Imports do próprio módulo
 from inewave._utils.leitura import Leitura
+from inewave._utils.bloco import Bloco
 from inewave.config import NUM_CENARIOS
 from inewave.config import MESES, SUBMERCADOS
 from .modelos.earmfpm00 import Earmfpm00
@@ -7,7 +8,7 @@ from .modelos.earmfpm00 import Earmfpm00
 import os
 import numpy as np  # type: ignore
 from traceback import print_exc
-from typing import IO, Dict, Tuple
+from typing import IO, Dict, Tuple, List
 
 
 class LeituraEarmfpm00(Leitura):
@@ -40,16 +41,18 @@ class LeituraEarmfpm00(Leitura):
 
     def __init__(self,
                  diretorio: str) -> None:
-        super().__init__()
-        self.diretorio = diretorio
+        super().__init__(diretorio)
         self.arquivos = self._lista_arquivos_por_chave("earmfpm00")
         self.earmfpms: Dict[str, Earmfpm00] = {}
 
+    def _cria_blocos_leitura(self) -> List[Bloco]:
+        pass
+
     def le_arquivos(self) -> Dict[str, Earmfpm00]:
         """
         Lê os arquivos earmfpm00x.out em um diretório.
         """
-        caminhos = [os.path.join(self.diretorio, f)
+        caminhos = [os.path.join(self._diretorio, f)
                     for f in self.arquivos]
         for a, c in zip(self.arquivos, caminhos):
             earmfpm = self._le_arquivo(c)
